## Tidyverse reminder----
# Tidyverse is a collection of R packages for dealing with data in the "tidy" format
# the tidyverse includes ggplot2 (graphics), dplyr (data manipulation), tidyr 
# (tidy format data), tibble (better version of data frames)
# Using Tidyverse is less like memorizing a bunch of specific commands and more like using
# a few general, but useful commands that you can string together logically using "pipes" ( %>% )

## Load data----
# the first step is to load the packages we need
# since we'll be using Tidyverse, install and load ("require") Tidyverse. 
# if you already have Tidyverse installed you don't need to run the first line
install.packages("tidyverse") # only do this the first time you load a package
require(tidyverse) 

# the next step is to figure out what directory we put the data in and navigate there so R 
# knows where to look
# this is like moving through your folders in a Finder window
# use the get working directory command, getwd() to figure out where you are
getwd()

# if you want to know what's in the directory (folder) where you are
list.files()

# then you can move around among files manually
setwd("/Users/juliannarenzi/Downloads/") # you'll want this to reflect your own path--mine won't work for you
list.files()

# now we want to read the CSV file in so we can start exploring our data
ne_aquatic_plants <- read_csv("Aquatic_flower_leaves_East_coast.csv")

# to check out what our data look like, let's see the top few rows (the "head" of the data)
ne_aquatic_plants %>% head
  # Our first ~ PIPE !! ~
  # can see that even here there are too many columns to see normally--need to look at what the columns are and look individually
ne_aquatic_plants %>% colnames

## Start Tidyverse----
# What types of species are there in this dataset? 
# Use piping + a Tidyverse core function!
ne_aquatic_plants %>% 
  select(Common_Name) %>% 
  unique
# "select" is a tidyverse command that picks columns

# to select everything but a particular column, put a minus sign before the column name
ne_aquatic_plants %>% 
  select(-Common_Name, -Observation_ID, -Site_ID) %>% 
  head

# if you want to get particular rows, use "filter" instead
# Select a particular species (rows with a particular value) susing "filter"
ne_practice <- ne_aquatic_plants[,c(7, 12:17)] # to practice, let's make a smaller dataframe with just a few columns of interest 
  ne_practice %>% head

ne_practice %>% 
  filter(Common_Name == "rockweed") 

ne_practice %>% 
  filter(Common_Name != "rockweed") # everything but versicolor

ne_practice %>% 
  filter(Common_Name == "rockweed" & Common_Name == "cranberry") # multiple criteria

ne_practice %>% 
  filter(Common_Name == "rockweed" | Common_Name == "cranberry") 
# "|" acts like an "or"

ne_practice %>% 
  filter(Common_Name == "rockweed" | Common_Name == "cranberry", Elevation_in_Meters > 30) 
# the comma acts like an "and" (or an "&" in the example above)
# notice you can filter quantatiative values based on ranges

# sort the dataset by elevation in meters
ne_practice %>% 
  arrange(Elevation_in_Meters) %>% head # increasing elevation

ne_practice %>% 
  arrange(-Elevation_in_Meters) %>% head # decreasing elevation

# to add new columns use "mutate"
# let's say, for instance, we want to add a new column with elevation in yards
ne_practice %>% 
  mutate(Elevation_in_Yards = Elevation_in_Meters * 0.9144) # make a new column with meter version
  # can also update the old column by using the original column name (replaces it! Be careful!)

# but it's not part of ne_practice? Why? Because we have to save it to make it stick 
# But you'll notice none of this is saved in "ne_practice" 
# if you want to replace ne_practice with the new tibble you've made, you can save it to ne_practice
# " -> ne_practice" at the end
# or you can save it as something else:
ne_practice %>%   
  mutate(Elevation_in_Yards = Elevation_in_Meters * 0.9144) -> boop
# now boop has the weird alterations we made and we can do more things to it without messing with ne_practice

boop[1:10,c(1,8)] # now we see the column has been added

# Now you might want to know something about your data
# For instance, what is the mean spring maximum?
ne_aquatic_plants %>% 
  summarize(meanTmax_Spring = mean(Tmax_Spring), sdTmax_Spring = sd(Tmax_Spring))
  # but something looks fishy here--there's no way that is the mean Tmax 
  # what's wrong? We didn't account for NA ("not applicable"/blank) values! Most datasets have different ways to deal with NA values

# let's figure out what Nature's Notebook uses for NA
ne_aquatic_plants %>% 
  select(Tmax_Spring) %>% 
  unique

ne_aquatic_plants %>% 
  mutate(Tmax_Spring = replace(Tmax_Spring, Tmax_Spring == -9999, NA)) -> ne_aquatic_plants

# did it work? Check
ne_aquatic_plants %>% 
  select(Tmax_Spring) %>% unique

# but probably just want to do this with all values in the tibble!
# Tidyverse functions (e.g. select, mutate, etc.) often have other versions of themselves. For example: 
ne_aquatic_plants %>% 
  mutate_all(~ replace(., . == -9999, NA)) -> ne_aquatic_plants

# now we can try again with more faith in the answer
ne_aquatic_plants %>% 
  summarize(meanTmax_Spring = mean(Tmax_Spring, na.rm = TRUE), sdTmax_Spring = sd(Tmax_Spring, na.rm = TRUE))
# "na.rm = TRUE" removes "not applicable" values (i.e. cells with no value that happen sometimes)
# there are almost always na's in real data--good to always be looking out for them 
# (they can mess with your analysis if you don't account for them properly)
# probably best to find these values in the beginning and filter them out for the whole analysis
# this is why data exploration is so important!

# but, we may not just be interested in the grand average, but rather the site-specific averages 
# in that case, "group_by()" is a useful function (also helpful in plotting)
ne_aquatic_plants %>% 
  group_by(Site_Name) %>% 
  summarize(meanTmax_Spring = mean(Tmax_Spring, na.rm = TRUE)) 

## Plotting with ggplot----
# ggplot is the Tidyverse package for plotting data
# every ggplot graph is made up of a few key parts that you specify by making a ggplot object
# in the main ggplot call you specify: 1. data, 2. x/y columns, 3. group_by/color, 4. group_by/shape

# this is a basic ggplot call with points
ggplot(data = ne_aquatic_plants, mapping = aes(x = Tmin_Winter,
                                  y = Day_of_Year)) +
  geom_point()

# maybe fit a spline to this (moving average) and add a theme!
ggplot(data = ne_aquatic_plants, mapping = aes(x = Tmin_Winter,
                                               y = Day_of_Year)) +
  geom_point() +
  geom_smooth() + 
  labs(x = "Winter Tmin (°C)",
       y = "Day of year") +
  theme_bw()

# or make it a linear model
ggplot(data = ne_aquatic_plants, mapping = aes(x = Tmin_Winter,
                                               y = Day_of_Year)) +
  geom_point() +
  geom_smooth(method = "lm")

# BUT really we want to know things about specific phenophases and spp
# color/shape by species 
ggplot(data = ne_aquatic_plants, 
       mapping = aes(x = Tmin_Winter, 
                     y = Day_of_Year, 
                     color = Common_Name, 
                     shape = Phenophase_Name)) + 
  geom_point() + 
  geom_smooth(method = "lm") + 
  labs(x = "Winter Tmin (°C)", 
       y = "DOY") # picture changes a lot here

# Now we could look at a species or phenophse more in depth
# what species has the most observations? 
table(ne_aquatic_plants$Common_Name) # Black willow!

# what phenophase is the most common?
ne_aquatic_plants %>% 
  filter(Common_Name == "black willow") %>% 
  select(Phenophase_Name) %>% 
  table # see breaking leaf buds is the most common

# let's make a little tibble with just the species of interest
ne_aquatic_plants %>% 
  filter(Common_Name == "black willow") -> black_willow

# check it out
black_willow$Day_of_Year %>% table %>% barplot # this looks weird!! Why?

# But we have to remember how our data are set up--how are phenophases recorded?
black_willow %>% 
  filter(Phenophase_Status == "1") %>% 
  ggplot(mapping = aes(x = Tmin_Winter,
                       y = Day_of_Year, 
                       color = Phenophase_Name)) + 
  geom_point(alpha=.2) + 
  geom_smooth(method = "lm") + 
  labs(x = "Winter Tmin (°C)", 
       y = "DOY",
       title = "Black willow phenophase observations") +
  theme_bw() + 
  theme(legend.title = element_blank(),
        legend.background = element_rect(fill = "lightgray"))

# Or maybe we want to see this in boxplot format
black_willow %>% 
  filter(Phenophase_Status == "1") %>% 
  ggplot(mapping = aes(x = Phenophase_Name,
                       y = Day_of_Year,
                       group = Phenophase_Name,
                       color = Phenophase_Name)) +
  geom_boxplot(outlier.colour="black", outlier.shape=16,
               outlier.size=2) +
  labs(x = "Phenophase",
       y = "Day of year",
       title = "Black willow 'yes' observations") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1))

# Or maybe we want a histogram
black_willow %>% 
  filter(Phenophase_Status == "1") %>% 
  filter(Phenophase_Name == "Breaking leaf buds") %>% 
  ggplot(mapping = aes(x = Day_of_Year)) +
  geom_histogram() +
  labs(x = "Day of year", 
       y = "Number of 'yes' observations",
       title = "Black willow: breaking leaf buds") +
  theme_bw() # looks normally distributed! Nice! 

# what if we want it by the year? Try the Tidyverse function separate!
# it separates where it sees a non-numeric character, or you can specify
black_willow %>% 
  separate(Observation_Date, into = c("Year", "Month", "Day")) -> black_willow_yr

black_willow_yr[,17:22] # see it worked!

black_willow_yr %>% 
  filter(Phenophase_Status == "1") %>% 
  filter(Phenophase_Name == "Breaking leaf buds") %>% 
  ggplot(mapping = aes(x = Day_of_Year)) +
           facet_wrap(~Year) +
           geom_histogram() + 
  theme_light()

## Practice----

## Q1: Practice moving directories. Can you move into a subfolder in your Documents folder and then 
# move into your downloads folder? What files are in your Documents folder?


## Q2: Make a new column that turns Tmax in Farenheight to Tmax in Celcius 


## Q3: How many states are in the dataset? How many unique genuses?  


## Q4: Choose a species to investigate more thoroughly--find out which phenophases are most commonly
# observed for it and where the observations are geographically, how many sites, etc.


## Q5: Pick a phenophase to look more closely at. Make a histograph of its occurences (1's)
# throughout the year--what kind of phenology distribution does it have? 


## Q6: What climate variables do you think might be influencing the occurence of the phenophase?
# Plot linear regressions of phenophases with different climate variables to explore which ones 
# might be important 


